/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @oma_ds_protocol_binder_definition.h
 *   @version									0.1
 *   @brief										This file is the header file for protocol binder definition
 */

#ifndef OMA_DS_PROTOCOL_BINDER_DEFINITION_H_
#define OMA_DS_PROTOCOL_BINDER_DEFINITION_H_

#define SYNC_AGENT_INIT_ESTIMATE_DOC_SIZE	20

/* SyncML */
#define ELEMENT_SYNCML	 "SyncML"

/* SyncHdr */
#define ELEMENT_SYNCHDR "SyncHdr"
#define ELEMENT_VERDTD "VerDTD"
#define ELEMENT_VERDRD_10 "1.0"
#define ELEMENT_VERDRD_11 "1.1"
#define ELEMENT_VERDRD_12 "1.2"
#define ELEMENT_VERPROTO "VerProto"
#define ELEMENT_VERPROTO_10 "SyncML/1.0"
#define ELEMENT_VERPROTO_11 "SyncML/1.1"
#define ELEMENT_VERPROTO_12 "SyncML/1.2"
#define ELEMENT_SESSIONID "SessionID"
#define ELEMENT_MSGID "MsgID"
#define ELEMENT_RESPURI "RespURI"
#define ELEMENT_NORESP "NoResp"
#define ELEMENT_CRED "Cred"

/* SyncBody */
#define ELEMENT_SYNCBODY "SyncBody"
#define ELEMENT_CMD "Cmd"
#define ELEMENT_ADD "Add"
#define ELEMENT_REPLACE "Replace"
#define ELEMENT_ALERT "Alert"
#define ELEMENT_SYNC "Sync"
#define ELEMENT_PUT "Put"
#define ELEMENT_REPLACE "Replace"
#define ELEMENT_DELETE "Delete"
#define ELEMENT_MAP "Map"
#define ELEMENT_GET "Get"
#define ELEMENT_RESULTS "Results"
#define ELEMENT_STATUS "Status"
#define ELEMENT_CMDID "CmdID"
#define ELEMENT_ITEM "Item"
#define ELEMENT_NUMBEROFCHANGES "NumberOfChanges"
#define ELEMENT_MSGREF "MsgRef"
#define ELEMENT_CMDREF "CmdRef"
#define ELEMENT_TARGETREF "TargetRef"
#define ELEMENT_SOURCEREF "SourceRef"
#define ELEMENT_MAPITEM "MapItem"
#define ELEMENT_MOREDATA "MoreData"
#define ELEMENT_TARGET "Target"
#define ELEMENT_SOURCE "Source"
#define ELEMENT_LOCURI "LocURI"
#define ELEMENT_LOCNAME "LocName"
#define ELEMENT_CHAL "Chal"
#define ELEMENT_B64 "b64"
#define ELEMENT_DATA "Data"

/* DevInf */
#define ELEMENT_DEVINF "DevInf"
#define ELEMENT_MAN "Man"
#define ELEMENT_MOD "Mod"
#define ELEMENT_OEM "OEM"
#define ELEMENT_FWV "FwV"
#define ELEMENT_SWV "SwV"
#define ELEMENT_HWV "HwV"
#define ELEMENT_DEVID "DevID"
#define ELEMENT_DEVTYP "DevTyp"
#define ELEMENT_PAGER "Pager"
#define ELEMENT_HANDHELD "handheld"
#define ELEMENT_PDA "pda"
#define ELEMENT_PHONE "phone"
#define ELEMENT_SMARTPHONE "smartphone"
#define ELEMENT_SERVER "server"
#define ELEMENT_WORKSTATION "workstation"
#define ELEMENT_UTC "UTC"
#define ELEMENT_SUPPORTLARGEOBJS "SupportLargeObjs"
#define ELEMENT_SUPPORTNUMBEROFCHANGES "SupportNumberOfChanges"
#define ELEMENT_DATASTORE "DataStore"
#define ELEMENT_DISPLAYNAME "DisplayName"
#define ELEMENT_MAXGUIDSIZE "MaxGUIDSize"
#define ELEMENT_RX_PREF "Rx-Pref"
#define ELEMENT_RX "Rx"
#define ELEMENT_TX_PREF "Tx-Pref"
#define ELEMENT_TX "Tx"
#define ELEMENT_CTCAP "CTCap"
#define ELEMENT_CTTYPE "CTType"
#define ELEMENT_VERCT "VerCT"
#define ELEMENT_FIELDLEVEL "FieldLevel"
#define ELEMENT_PROPERTY "Property"
#define ELEMENT_PROPNAME "PropName"
#define ELEMENT_DATATYPE "DataType"
#define ELEMENT_MAXOCCUR "MaxOccur"
#define ELEMENT_MAXSIZE "MaxSize"
#define ELEMENT_NOTRUNCATE "NoTruncate"
#define ELEMENT_VALENUM "ValEnum"
#define ELEMENT_DISPLAYNAME "DisplayName"
#define ELEMENT_PROPPARAM "PropParam"
#define ELEMENT_PARAMNAME "ParamName"
#define ELEMENT_DSMEM "DSMem"
#define ELEMENT_SHAREDMEM "SharedMem"
#define ELEMENT_MAXMEM "MaxMem"
#define ELEMENT_MAXID "MaxID"
#define ELEMENT_SUPPORTHIERARCHICALSYNC "SupportHierarchicalSync"
#define ELEMENT_SYNCCAP "SyncCap"
#define ELEMENT_SYNCTYPE "SyncType"
#define ELEMENT_SYNCTYPE_1 "1"
#define ELEMENT_SYNCTYPE_2 "2"
#define ELEMENT_SYNCTYPE_3 "3"
#define ELEMENT_SYNCTYPE_4 "4"
#define ELEMENT_SYNCTYPE_5 "5"
#define ELEMENT_SYNCTYPE_6 "6"
#define ELEMENT_SYNCTYPE_7 "7"
#define ELEMENT_FILTER_RX "Filter-Rx"
#define ELEMENT_FILTERCAP "FilterCap"

/* MetInf */
#define ELEMENT_META "Meta"
#define ELEMENT_FORMAT "Format"
#define ELEMENT_NEXTNONCE "NextNonce"
#define ELEMENT_TYPE "Type"
#define ELEMENT_SIZE "Size"
#define ELEMENT_MAXMSGSIZE "MaxMsgSize"
#define ELEMENT_MAXOBJSIZE "MaxObjSize"
#define ELEMENT_ANCHOR "Anchor"
#define ELEMENT_LAST "Last"
#define ELEMENT_NEXT "Next"
#define ELEMENT_MEM "Mem"
#define ELEMENT_SHAREDMEM "SharedMem"
#define ELEMENT_FREEMEM "FreeMem"
#define ELEMENT_FREEID "FreeID"

typedef enum {
	PE_UNDEF = 0,
	PE_ERROR,
	PE_ADD,
	PE_ALERT,
	PE_ATOMIC_START,
	PE_ATOMIC_END,
	PE_COPY,
	PE_DELETE,
	PE_EXEC,
	PE_GET,
	PE_MAP,
	PE_PUT_START,
	PE_PUT_END,
	PE_RESULTS_START,
	PE_RESULTS_END,
	PE_SEARCH,
	PE_SEQUENCE_START,
	PE_SEQUENCE_END,
	PE_STATUS,
	PE_SYNC_START,
	PE_SYNC_END,
	PE_REPLACE,
	PE_HEADER,
	PE_PUT_GET,
	PE_CMD_GROUP,
	PE_GENERIC,
	PE_FINAL,
	PE_DEVINF,
	PE_SYNCML_START,
	PE_SYNCML_END,
	PE_BODY_START,
	PE_BODY_END
} oma_ds_protocol_element_e;

#endif				/* OMA_DS_PROTOCOL_BINDER_DEFINITION_H_ */
